;; Generated package description from project.el  -*- no-byte-compile: t -*-
(define-package "project" "0.11.2" "Operations on the current project" '((emacs "26.1") (xref "1.7.0")) :commit "b8ff1c1fae9860f48a954bd97d68b5cf2c643285" :url "https://elpa.gnu.org/packages/project.html")
